==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AIdentClassName.h <==
// public final class soot.jimple.parser.node.AIdentClassName

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c1697a04c71071b9 soot_jimple_parser_node_AIdentClassName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5677865048a744c3 soot_jimple_parser_node_PClassName

// header file dependencies
// @dep_header soot_jimple_parser_node_PClassName

#include "soot/jimple/parser/node/PClassName.h"

#ifndef _JC_soot_jimple_parser_node_AIdentClassName_H_
#define _JC_soot_jimple_parser_node_AIdentClassName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TIdentifier$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AIdentClassName$sub_refs	_jc_soot_jimple_parser_node_AIdentClassName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AIdentClassName$sub_nonrefs	_jc_soot_jimple_parser_node_AIdentClassName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AIdentClassName$refs	_jc_soot_jimple_parser_node_AIdentClassName$refs;
typedef struct _jc_soot_jimple_parser_node_AIdentClassName$nonrefs	_jc_soot_jimple_parser_node_AIdentClassName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AIdentClassName$object	_jc_soot_jimple_parser_node_AIdentClassName$object;

typedef const struct _jc_soot_jimple_parser_node_AIdentClassName$vmethods	_jc_soot_jimple_parser_node_AIdentClassName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AIdentClassName$vtable	_jc_soot_jimple_parser_node_AIdentClassName$vtable;
typedef const struct _jc_soot_jimple_parser_node_AIdentClassName$vtype	_jc_soot_jimple_parser_node_AIdentClassName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AIdentClassName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *);
extern void _jc_soot_jimple_parser_node_AIdentClassName$method$_init$1ad09019f97846a0(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *, struct _jc_soot_jimple_parser_node_TIdentifier$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AIdentClassName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AIdentClassName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *);
extern struct _jc_soot_jimple_parser_node_TIdentifier$object *_jc_soot_jimple_parser_node_AIdentClassName$method$getIdentifier$0f5ff549a337596f(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *);
extern void _jc_soot_jimple_parser_node_AIdentClassName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AIdentClassName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AIdentClassName$method$setIdentifier$2a6f9c69a5ef4095(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *, struct _jc_soot_jimple_parser_node_TIdentifier$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AIdentClassName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AIdentClassName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AIdentClassName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AIdentClassName$method_info$getIdentifier$0f5ff549a337596f;
extern _jc_method _jc_soot_jimple_parser_node_AIdentClassName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AIdentClassName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AIdentClassName$method_info$setIdentifier$2a6f9c69a5ef4095;
extern _jc_method _jc_soot_jimple_parser_node_AIdentClassName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AIdentClassName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *);
	struct _jc_soot_jimple_parser_node_TIdentifier$object	*(*getIdentifier$0f5ff549a337596f)(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setIdentifier$2a6f9c69a5ef4095)(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *, struct _jc_soot_jimple_parser_node_TIdentifier$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AIdentClassName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PClassName$vmethods	soot_jimple_parser_node_PClassName;
	_jc_soot_jimple_parser_node_AIdentClassName$vmethods	soot_jimple_parser_node_AIdentClassName;
};

// Vtype
struct _jc_soot_jimple_parser_node_AIdentClassName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AIdentClassName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AIdentClassName$sub_refs {
	struct _jc_soot_jimple_parser_node_TIdentifier$object	*__5fidentifier__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AIdentClassName$refs {
    _jc_soot_jimple_parser_node_AIdentClassName$sub_refs	soot_jimple_parser_node_AIdentClassName;
    _jc_soot_jimple_parser_node_PClassName$sub_refs	soot_jimple_parser_node_PClassName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AIdentClassName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AIdentClassName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PClassName$sub_nonrefs	soot_jimple_parser_node_PClassName;
    _jc_soot_jimple_parser_node_AIdentClassName$sub_nonrefs	soot_jimple_parser_node_AIdentClassName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AIdentClassName$object {
	_jc_soot_jimple_parser_node_AIdentClassName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AIdentClassName$vtype	*vtype;
	_jc_soot_jimple_parser_node_AIdentClassName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AIdentClassName$vtype _jc_soot_jimple_parser_node_AIdentClassName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AIdentClassName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AIdentClassName$class_object;

#endif	/* _JC_soot_jimple_parser_node_AIdentClassName_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AIdentClassName.h <==
// public final class soot.jimple.parser.node.AIdentClassName

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c1697a04c71071b9 soot_jimple_parser_node_AIdentClassName
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 5677865048a744c3 soot_jimple_parser_node_PClassName

// header file dependencies
// @dep_header soot_jimple_parser_node_PClassName

#include "soot/jimple/parser/node/PClassName.h"

#ifndef _JC_soot_jimple_parser_node_AIdentClassName_H_
#define _JC_soot_jimple_parser_node_AIdentClassName_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TIdentifier$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AIdentClassName$sub_refs	_jc_soot_jimple_parser_node_AIdentClassName$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AIdentClassName$sub_nonrefs	_jc_soot_jimple_parser_node_AIdentClassName$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AIdentClassName$refs	_jc_soot_jimple_parser_node_AIdentClassName$refs;
typedef struct _jc_soot_jimple_parser_node_AIdentClassName$nonrefs	_jc_soot_jimple_parser_node_AIdentClassName$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AIdentClassName$object	_jc_soot_jimple_parser_node_AIdentClassName$object;

typedef const struct _jc_soot_jimple_parser_node_AIdentClassName$vmethods	_jc_soot_jimple_parser_node_AIdentClassName$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AIdentClassName$vtable	_jc_soot_jimple_parser_node_AIdentClassName$vtable;
typedef const struct _jc_soot_jimple_parser_node_AIdentClassName$vtype	_jc_soot_jimple_parser_node_AIdentClassName$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AIdentClassName$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AIdentClassName$method$_init$1ad09019f97846a0(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *, struct _jc_soot_jimple_parser_node_TIdentifier$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AIdentClassName$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AIdentClassName$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TIdentifier$object *_jc_soot_jimple_parser_node_AIdentClassName$method$getIdentifier$0f5ff549a337596f(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AIdentClassName$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AIdentClassName$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AIdentClassName$method$setIdentifier$2a6f9c69a5ef4095(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *, struct _jc_soot_jimple_parser_node_TIdentifier$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AIdentClassName$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AIdentClassName$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AIdentClassName$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AIdentClassName$method_info$getIdentifier$0f5ff549a337596f;
extern _jc_method _jc_soot_jimple_parser_node_AIdentClassName$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AIdentClassName$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AIdentClassName$method_info$setIdentifier$2a6f9c69a5ef4095;
extern _jc_method _jc_soot_jimple_parser_node_AIdentClassName$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AIdentClassName$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TIdentifier$object	*(*getIdentifier$0f5ff549a337596f)(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setIdentifier$2a6f9c69a5ef4095)(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *, struct _jc_soot_jimple_parser_node_TIdentifier$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AIdentClassName$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PClassName$vmethods	soot_jimple_parser_node_PClassName;
	_jc_soot_jimple_parser_node_AIdentClassName$vmethods	soot_jimple_parser_node_AIdentClassName;
};

// Vtype
struct _jc_soot_jimple_parser_node_AIdentClassName$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AIdentClassName$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AIdentClassName$sub_refs {
	struct _jc_soot_jimple_parser_node_TIdentifier$object	*__5fidentifier__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AIdentClassName$refs {
    _jc_soot_jimple_parser_node_AIdentClassName$sub_refs	soot_jimple_parser_node_AIdentClassName;
    _jc_soot_jimple_parser_node_PClassName$sub_refs	soot_jimple_parser_node_PClassName;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AIdentClassName$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AIdentClassName$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PClassName$sub_nonrefs	soot_jimple_parser_node_PClassName;
    _jc_soot_jimple_parser_node_AIdentClassName$sub_nonrefs	soot_jimple_parser_node_AIdentClassName;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AIdentClassName$object {
	_jc_soot_jimple_parser_node_AIdentClassName$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AIdentClassName$vtype	*vtype;
	_jc_soot_jimple_parser_node_AIdentClassName$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AIdentClassName$vtype _jc_soot_jimple_parser_node_AIdentClassName$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AIdentClassName, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AIdentClassName$class_object;

#endif	/* _JC_soot_jimple_parser_node_AIdentClassName_H_ */
